window.Gleam.initSearch([{"doc":"rsa_keys","title":"rsa_keys","content":"# rsa_keys\n\n[![Package Version](https://img.shields.io/hexpm/v/rsa_keys)](https://hex.pm/packages/rsa_keys)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/rsa_keys/)\n\nA small library to help with RSA keys.\n\n## installation\n\n```sh\ngleam add rsa_keys\n```\n\n## example usage\n\n```gleam\nimport rsa_keys\n\npub fn main() {\n  \n  let #(pubkey, prvtkey) = rsa_keys.generate_rsa_keys()\n\n  let result = {\n    use signature &lt;- result.try(rsa_keys.sign_message(\n      bit_array.from_string(&quot;ola mundo&quot;),\n      prvtkey,\n    ))\n    rsa_keys.verify_message(\n      message: bit_array.from_string(&quot;ola mundo&quot;),\n      public_key: pubkey,\n      signature: signature,\n    )\n  }\n  should.be_ok(result)\n  |&gt; should.be_true\n\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/rsa_keys&gt;.\n\nMany thanks to the discord user julian.nz in the gleam discord server for the help with the erlang ffi\n","url":"index.html"},{"doc":"rsa_keys","title":"ErrorDecrypt","content":"pub type ErrorDecrypt {\n  Integrity\n  Format\n}\n representation of decrypting errors \nIntegrity\n\n\nFormat\n\n\nSynonyms:\nrsa_keys.ErrorDecrypt\nrsa_keys ErrorDecrypt","url":"rsa_keys.html#ErrorDecrypt"},{"doc":"rsa_keys","title":"PrivateKey","content":"pub type PrivateKey {\n  PrivateKey(der: BitArray, pem: String)\n}\n\nPrivateKey(der: BitArray, pem: String)\n\n\nSynonyms:\nrsa_keys.PrivateKey\nrsa_keys PrivateKey","url":"rsa_keys.html#PrivateKey"},{"doc":"rsa_keys","title":"PublicKey","content":"pub type PublicKey {\n  PublicKey(der: BitArray, pem: String)\n}\n\nPublicKey(der: BitArray, pem: String)\n\n\nSynonyms:\nrsa_keys.PublicKey\nrsa_keys PublicKey","url":"rsa_keys.html#PublicKey"},{"doc":"rsa_keys","title":"decode_pem_to_der","content":"pub fn decode_pem_to_der(\n  pem_encoded_key key: String,\n) -&gt; Result(BitArray, String)\n Decode a pem key to a der binary\nSynonyms:\nrsa_keys.decode_pem_to_der\nrsa_keys decode_pem_to_der","url":"rsa_keys.html#decode_pem_to_der"},{"doc":"rsa_keys","title":"decrypt_message","content":"pub fn decrypt_message(\n  message msg: BitArray,\n  private_key prvtkey: PrivateKey,\n) -&gt; Result(BitArray, ErrorDecrypt)\n decrypt a message and it&#39;s hash, compare the two and return it if valid.\nSynonyms:\nrsa_keys.decrypt_message\nrsa_keys decrypt_message","url":"rsa_keys.html#decrypt_message"},{"doc":"rsa_keys","title":"encrypt_message","content":"pub fn encrypt_message(\n  message msg: BitArray,\n  pubkey pubkey: PublicKey,\n) -&gt; BitArray\n encrypt a message and a hash attached to it&#39;s end for proper validation later.\n the message can then be base 16 encoded for readability/storage.\nSynonyms:\nrsa_keys.encrypt_message\nrsa_keys encrypt_message","url":"rsa_keys.html#encrypt_message"},{"doc":"rsa_keys","title":"generate_rsa_keys","content":"pub fn generate_rsa_keys() -&gt; #(PublicKey, PrivateKey)\n Generate public and private RSA key pairs.\n\n The pem records are PEM encoded and thus human readable.\nSynonyms:\nrsa_keys.generate_rsa_keys\nrsa_keys generate_rsa_keys","url":"rsa_keys.html#generate_rsa_keys"},{"doc":"rsa_keys","title":"sign_message","content":"pub fn sign_message(\n  message msg: BitArray,\n  private_key prvtkey: PrivateKey,\n) -&gt; Result(BitArray, String)\n Hash a message using sha256 and sign it using a private key.\n\n The returned signature can then be base16 encoded for readability.\nSynonyms:\nrsa_keys.sign_message\nrsa_keys sign_message","url":"rsa_keys.html#sign_message"},{"doc":"rsa_keys","title":"sign_message_with_pem_string","content":"pub fn sign_message_with_pem_string(\n  message msg: BitArray,\n  private_key_pem prvtkey_pem: String,\n) -&gt; Result(BitArray, String)\n Same as sign_message but uses pem string as the argument.\nSynonyms:\nrsa_keys.sign_message_with_pem_string\nrsa_keys sign_message_with_pem_string","url":"rsa_keys.html#sign_message_with_pem_string"},{"doc":"rsa_keys","title":"verify_message","content":"pub fn verify_message(\n  message msg: BitArray,\n  public_key public_key: PublicKey,\n  signature signature: BitArray,\n) -&gt; Result(Bool, String)\n verify a message against its sha256 hash and signature using a public key.\n\n returns a Ok(True) for valid signature\n\n returns a Ok(False) for invalid signature\n\n returns an Error for runtime issues.\nSynonyms:\nrsa_keys.verify_message\nrsa_keys verify_message","url":"rsa_keys.html#verify_message"},{"doc":"rsa_keys","title":"verify_message_with_pem_string","content":"pub fn verify_message_with_pem_string(\n  message msg: BitArray,\n  public_key_pem_string public_key_pem: String,\n  signature signature: BitArray,\n) -&gt; Result(Bool, String)\n Same as verify_message but with pem string as the argument.\nSynonyms:\nrsa_keys.verify_message_with_pem_string\nrsa_keys verify_message_with_pem_string","url":"rsa_keys.html#verify_message_with_pem_string"},{"doc":"rsa_keys","title":"rsa_keys","content":" Simple and easy set of functions to generate rsa keys, sign a message and verify it, targeting erlang.\n\n Funções simples e fáceis para gerar chaves rsa, assinar uma mensagem e verificála, usando erlang.","url":"rsa_keys.html"}]);